Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5882)

Unified Diff: chrome/browser/ui/webui/web_ui_util.h

Issue 10453101: Convert most of the rest of chrome to ImageSkia (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/web_ui_util.h
diff --git a/chrome/browser/ui/webui/web_ui_util.h b/chrome/browser/ui/webui/web_ui_util.h
index 99a2b46570adab2f6a38aef462b94d3d3e8ebbff..5a5e6d23f9db3dad266f3e6ef082e870a4d14bb2 100644
--- a/chrome/browser/ui/webui/web_ui_util.h
+++ b/chrome/browser/ui/webui/web_ui_util.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -11,13 +11,15 @@
#include "base/values.h"
#include "webkit/glue/window_open_disposition.h"
-class SkBitmap;
+namespace gfx {
+class ImageSkia;
+}
namespace web_ui_util {
// Convenience routine to convert SkBitmap object to data url
// so that it can be used in WebUI.
-std::string GetImageDataUrl(const SkBitmap& bitmap);
+std::string GetImageDataUrl(const gfx::ImageSkia& image);
// Convenience routine to get data url that corresponds to given
// resource_id as an image. This function does not check if the
« no previous file with comments | « chrome/browser/ui/webui/task_manager/task_manager_handler.cc ('k') | chrome/browser/ui/webui/web_ui_util.cc » ('j') | no next file with comments »
@@ -11,13 +11,15 @@
namespace web_ui_util {
-// Convenience routine to convert SkBitmap object to data url
+// Convenience routine to convert ImageSkia object to data url
// so that it can be used in WebUI.

Powered by Google App Engine
This is Rietveld 408576698